@@ -649,7 +649,7 @@ def get_template(key, key_option, revision, history, query_all, query, format, v
 @command_doc(CLI_COMMANDS_HELP['template']['add'])
 @click.argument('key', required=False)
 @click.option('-k', '--key', 'key_option', metavar='<key>', required=False, help=f"{CLI_PARAMETERS_HELP['template']['key']}")
-@click.option('-r', '--render-path', default='.', show_default=True, metavar='<path>', required=False, help=f"{CLI_PARAMETERS_HELP['template']['render_path']}")
+@click.option('-r', '--render-path', show_default=True, metavar='<path>', required=False, help=f"{CLI_PARAMETERS_HELP['template']['render_path']}")
 @click.option('-i', '--input', metavar='<path>', required=True, type=click.Path(exists=False, file_okay=True, dir_okay=True), callback=check_file_path, help=f"{CLI_PARAMETERS_HELP['template']['input']}")
 @click.option('--recursive', required=False, is_flag=True, help=f"{CLI_PARAMETERS_HELP['template']['recursive']}")
 @click.option('-b', '--verbosity', metavar='<number>', required=False, type=RangeParamType(click.INT, minimum=0, maximum=5), default='2', show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['verbosity']}")
@@ -663,36 +663,54 @@ def add_template(key, key_option, render_path, input, recursive, verbosity, glob
 
     def process_key_from_path(path):
 
-        if not key or key in ['.' , './']:
+        if not key:
             if os.path.samefile(path, input):
                 return os.path.basename(path)
             else:
                 return path[len(input)+1:]
 
         result = key
-        ### if **/ exist in key, replace it with path dirname
+        ### if ** exist in key, replace it with path dirname
         if os.path.dirname(path)[len(input):]:
             result = result.replace('**', os.path.dirname(path)[len(input)+1:])
         else:
-            result = result.replace(f'**{os.sep}', '')
             result = result.replace('**', '')
+        ### if * exist in key, replace it with path basename
         result = result.replace('*', os.path.basename(path))
-        result = result.replace(f"{os.sep}{os.sep}", os.sep)
+        ### fix possiblly created // to /
+        result = result.replace(f'{os.sep}{os.sep}', os.sep)
+        ### fix possiblly trailing /
+        result = re.sub(f'{os.sep}$', '', result)
 
         return result
 
 
     def process_render_path_from_key(key):
-        ### by default render_path is '.'
-        result = ''
-        if render_path == '.' or render_path == './':
-            result = key
+
+        if not render_path or render_path in ['.', f'.{os.sep}']:
+            return key
+
+        result = render_path
+        ### if ** exist in render_path, replace it with key dirname
+        if os.path.dirname(key):
+            result = result.replace('**', os.path.dirname(key))
         else:
-            if os.path.dirname(key):
-                result = re.sub(r'[*][*]', os.path.dirname(key), render_path)
-            else:
-                result = re.sub(os.sep + r'[*][*]', '', render_path)
-            result = re.sub(r'[*]', os.path.basename(key), result)
+            result = result.replace('**', '')
+        ### if * exist in key, replace it with path basename
+        result = result.replace('*', os.path.basename(key))
+        ### fix possiblly created // to /
+        result = result.replace(f'{os.sep}{os.sep}', os.sep)
+        ### fix possiblly trailing /
+        result = re.sub(f'{os.sep}$', '', result)
+
+        if os.path.isabs(result):
+            Logger.warn(CLI_MESSAGES['RenderPathNotReleative'].format(result))
+        else:
+            if not result.startswith(f".{os.sep}"):
+                result = os.path.join(f".{os.sep}", result)
+
+        if os.path.isdir(result):
+            raise DSOException(CLI_MESSAGES['InvalidRenderPathExistingDir'].format(result))
 
         return result
 
@@ -708,9 +726,11 @@ def add_template(key, key_option, render_path, input, recursive, verbosity, glob
             else:
                 globe = f'{os.sep}*'
             path = input + globe
+
         else:
             path = input
 
+        ### processing templates from path
         for item in glob.glob(path, recursive=recursive):
             if not Path(item).is_file(): continue
             if is_binary_file(item):
