@@ -2,12 +2,14 @@
 APPLICATION_NAME = "DSO Tool"
 REGEX_PATTERNS = {
     'stage' : r"^([a-zA-Z][a-zA-Z0-9]+)/?([0-9])?$",
-    # 'parameter_key' : r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$",
-    # 'parameter_key_value' : r"^([a-zA-Z][a-zA-Z0-9_.-/]*)=(.*)$",
+    'parameter_key': r"^([a-zA-Z][a-zA-Z0-9_.-]*[a-zA-ZA-Z0-9_-])$",
+    'secret_key': r"^([a-zA-Z][a-zA-Z0-9_.-]*[a-zA-ZA-Z0-9_-])$",
+    'template_key': r"^([a-zA-Z][a-zA-Z0-9_.-/]*[a-zA-ZA-Z0-9_-])$",
 }
 
 MESSAGES = {
-    'InvalidKey': "'{0}' is an invalid key. Must conform to '{1}'",
+    'InvalidKeyPattern': "'{0}' is an invalid key. Must conform to '{1}'.",
+    'InvalidKeyStr': "'{0}' is an invalid key. Cannot contain '{1}'.",
     'ParameterNotFound': "Parameter '{0}' not found in the given context.",
     'SecretNotFound': "Secret '{0}' not found in the given context.",
     'InvalidStage': "'{0}' is not a valid stage name. Valid form is <string>[/number], where it must conform to '{1}'.",
@@ -28,9 +30,6 @@ MESSAGES = {
     'DSOConfigurationNotFound': 'DSO configuration not found.',
     'NoDSOConfigFound': "No DSO configuration found in the working directory.",
     'EnteredSecretValuesNotMatched': "Entered values for the secret did not macth.",
-    'InvalidRenderPath': "'{0}' is not a valid render path.",
-    'InvalidRenderPathExistingDir': "'{0}' is not a valid render path because it is an existing directory.",
-    'InvalidRenderPathAbs': "'{0}' is not a valid render path becasue render path must be relative to the root of the DSO application.",
     'QueryOptionCompatibleFormats': "Option '-q' / '--query' can be used only with 'json'/'yaml' output formats.",
     'QueryAllOptionNonCompatibleFormats': "Option '-a'/ '--query-all' cannot be used with 'shell' output format.",
 }
