@@ -14,14 +14,17 @@ from .exceptions import DSOException
 from .stages import Stages
 
 class TemplateProvider(StoreProvider):
-    def list(self):
+    def list(self, project, application, uninherited):
         raise NotImplementedError()
-    def add(self, key, contents, render_path):
+    def add(self, project, application, key, contents):
         raise NotImplementedError()
-    def delete(self, key, starts_with):
+    def delete(self, project, application, key):
         raise NotImplementedError()
-    def get(self, key):
+    def get(self, project, application, key, revision=None):
         raise NotImplementedError()
+    def history(self, project, application, key):
+        raise NotImplementedError()
+
 
 class TemplateManager():
 
@@ -30,9 +33,17 @@ class TemplateManager():
         return Configs.working_dir
 
     def validate_key(self, key):
-        provider = Providers.TemplateProvider()
         Logger.info("Start validating template key...")
-        return provider.validate_key(key)
+        Logger.debug(f"Validating: key={key}")
+        pattern = REGEX_PATTERNS['template_key']
+        if not re.match(pattern, key):
+            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, pattern))
+        ### the regex does not check adjacent special chars
+        if '..' in key:
+            raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '..'))
+
+        if '//' in key:
+            raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '//'))
 
     def list(self, uninherited=False):
         project = Configs.project
@@ -46,10 +57,10 @@ class TemplateManager():
             key = template['Key']
             if key in renderPaths:
                 renderPath = renderPaths[key]
-                if not (renderPath == '.' or renderPath.startswith(f'.{os.sep}')):
-                    renderPath = os.path.join('./', renderPath)
+                # if not (renderPath == '.' or renderPath.startswith(f'.{os.sep}')):
+                #     renderPath = os.path.join('./', renderPath)
             else:
-                renderPath = os.path.join(renderBasePath, key)
+                renderPath = f'.{os.sep}' + os.path.relpath(os.path.join(renderBasePath, key), Configs.working_dir) 
 
             template['RenderTo'] = renderPath
         
@@ -62,23 +73,22 @@ class TemplateManager():
         provider = Providers.TemplateProvider()
         # if '..' in render_path:
         #     raise DSOException(MESSAGES['InvalidRenderPath'].format(render_path))
-        if render_path == '.' or render_path == './':
-            render_path = os.path.join(self.default_render_path, key)
-        else:
-            if '**' in render_path:
-                render_path = render_path.replace('**', os.path.dirname(key))
-            if '*' in render_path:
-                render_path = render_path.replace('*', os.path.basename(key))
-        if not re.match('^[A-Za-z0-9._/$-]+$', render_path):
-            raise DSOException(MESSAGES['InvalidRenderPath'].format(render_path))
-        if os.path.isdir(render_path):
-            raise DSOException(MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
-        if os.path.isabs(render_path):
-            Logger.warn(f"Render path {render_path} is not releative to the application root.")
-        else:
-            if not (render_path == '.' or render_path.startswith(f".{os.sep}")):
-                render_path = os.path.join(f".{os.sep}", render_path)
-
+        # if render_path == '.' or render_path == f".{os.sep}":
+        #     render_path = os.path.relpath(os.path.join(self.default_render_path, key), Configs.working_dir)
+        # else:
+        #     if '**' in render_path:
+        #         render_path = render_path.replace('**', os.path.dirname(key))
+        #     if '*' in render_path:
+        #         render_path = render_path.replace('*', os.path.basename(key))
+        # if not re.match('^[A-Za-z0-9._/$-]+$', render_path):
+        #     raise DSOException(MESSAGES['InvalidRenderPath'].format(render_path))
+        # if os.path.isdir(render_path):
+        #     raise DSOException(MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
+        # if os.path.isabs(render_path):
+        #     Logger.warn(f"Render path {render_path} is not releative to the application root.")
+        # else:
+        #     if not (render_path == '.' or render_path.startswith(f".{os.sep}")):
+        #         render_path = os.path.join(f".{os.sep}", render_path)
         try:
             Logger.info(f"Start adding template: project={project}, application={application}, key={key}, render_path={render_path}")
             result = provider.add(project, application, key, contents)
